@@ -3,17 +3,15 @@
 
 import sqlalchemy as sa
 
-from holmes.models import Base, JsonType
+from holmes.models import Base, JsonTypeGzipped
 
 
 class Fact(Base):
     __tablename__ = "facts"
 
     id = sa.Column(sa.Integer, primary_key=True)
-    # key = sa.Column('key', sa.String(2000), nullable=False)
-    value = sa.Column('value', JsonType, nullable=False)
-    #title = sa.Column('title', sa.String(2000), nullable=False)
-    #unit = sa.Column('unit', sa.String(2000), nullable=False)
+
+    value = sa.Column('value', JsonTypeGzipped, nullable=False)
 
     review_id = sa.Column('review_id', sa.Integer, sa.ForeignKey('reviews.id'))
     # review comes from Review relationship
