@@ -33,7 +33,8 @@ from holmes.handlers.settings import (
     TaxHandler
 )
 from holmes.handlers.request import (
-    RequestDomainHandler, LastRequestsHandler, RequestsInLastDayHandler
+    RequestDomainHandler, LastRequestsHandler, FailedResponsesHandler,
+    LastRequestsStatusCodeHandler
 )
 from holmes.handlers.limiter import LimiterHandler
 
@@ -111,7 +112,8 @@ class HolmesApiServer(Server):
             ('/limiters/(%s)/?' % numbers_regex, LimiterHandler),
             ('/next-jobs/?', NextJobHandler),
             ('/last-requests/?', LastRequestsHandler),
-            ('/requests-in-last-day/?', RequestsInLastDayHandler),
+            ('/last-requests/status-code/?', LastRequestsStatusCodeHandler),
+            ('/last-requests/failed-responses/?', FailedResponsesHandler),
             ('/version/?', VersionHandler),
         ]
 
